/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.uinfo.inundationduration;

import java.util.ArrayList;
import java.util.Collection;

import org.dive4elements.river.artifacts.common.AbstractCalculationExportableResult;
import org.dive4elements.river.artifacts.common.ExportContextCSV;
import org.dive4elements.river.artifacts.common.GeneralResultType;
import org.dive4elements.river.artifacts.common.MetaAndTableJRDataSource;
import org.dive4elements.river.artifacts.common.ResultRow;
import org.dive4elements.river.artifacts.sinfo.common.SInfoResultType;
import org.dive4elements.river.artifacts.sinfo.util.RiverInfo;
import org.dive4elements.river.artifacts.sinfo.util.WstInfo;

/**
 * @author Domenico Nardi Tironi
 */
final class InundationDurationCalculationResult extends AbstractCalculationExportableResult<InundationDurationCalculationResults> {

    private static final long serialVersionUID = 1L;
    private static final String JASPER_FILE = "/jasper/templates/uinfo.inundationduration.jrxml";

    public InundationDurationCalculationResult(final String label, final WstInfo wst, final Collection<ResultRow> rows) {
        super(label, rows);
    }

    @Override
    public void writeCSVHeader(final ExportContextCSV exportContextCSV, final InundationDurationCalculationResults results, final RiverInfo river) {

        final Collection<String> header = new ArrayList<>(11);

        header.add(exportContextCSV.formatCsvHeader(GeneralResultType.station));
        header.add(exportContextCSV.msgUnitCSV(SInfoResultType.flowdepth));

        header.add(exportContextCSV.msgUnitCSV(SInfoResultType.waterlevel, river.getWstUnit()));
        header.add(exportContextCSV.msgUnitCSV(SInfoResultType.discharge));
        header.add(exportContextCSV.formatCsvHeader(SInfoResultType.waterlevelLabel));
        header.add(exportContextCSV.formatCsvHeader(SInfoResultType.gaugeLabel));
        header.add(exportContextCSV.msgUnitCSV(SInfoResultType.meanBedHeight, river.getWstUnit()));
        header.add(exportContextCSV.formatCsvHeader(SInfoResultType.soundingLabel));
        header.add(exportContextCSV.formatCsvHeader(SInfoResultType.location));

        exportContextCSV.writeCSVLine(header.toArray(new String[header.size()]));

    }

    @Override
    protected void writeCSVResultMetadata(final ExportContextCSV exportContextCSV, final InundationDurationCalculationResults results) {
        // no Result metadata so far
    }

    @Override
    protected String[] formatCSVRow(final ExportContextCSV exportContextCSV, final InundationDurationCalculationResults results, final ResultRow row) {
        return formatRow(exportContextCSV, results, row);
    }

    @Override
    protected String[] formatPDFRow(final ExportContextCSV exportContextPDF, final InundationDurationCalculationResults results, final ResultRow row) {

        return formatRow(exportContextPDF, results, row);
    }

    @Override
    protected String getJasperFile() {

        return JASPER_FILE;
    }

    @Override
    protected void addJRTableHeader(final ExportContextCSV exportContextPDF, final MetaAndTableJRDataSource source,
            final InundationDurationCalculationResults results) {

        exportContextPDF.addJRMetadata(source, "station_header", GeneralResultType.station);
    }

    protected String[] formatRow(final ExportContextCSV context, final InundationDurationCalculationResults results, final ResultRow row) {

        final Collection<String> lines = new ArrayList<>(11);

        lines.add(context.formatRowValue(row, GeneralResultType.station));
        lines.add(context.formatRowValue(row, SInfoResultType.flowdepth));

        lines.add(context.formatRowValue(row, SInfoResultType.waterlevel));
        lines.add(context.formatRowValue(row, SInfoResultType.discharge));
        lines.add(context.formatRowValue(row, SInfoResultType.waterlevelLabel));
        lines.add(context.formatRowValue(row, SInfoResultType.gaugeLabel));
        lines.add(context.formatRowValue(row, SInfoResultType.meanBedHeight));
        lines.add(context.formatRowValue(row, SInfoResultType.soundingLabel));
        lines.add(context.formatRowValue(row, SInfoResultType.location));

        return lines.toArray(new String[lines.size()]);
    }

}